aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/includes/config
diff options
context:
space:
mode:
Diffstat (limited to 'phpBB/includes/config')
-rw-r--r--phpBB/includes/config/config.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/phpBB/includes/config/config.php b/phpBB/includes/config/config.php
index a273391dc8..354dc85c03 100644
--- a/phpBB/includes/config/config.php
+++ b/phpBB/includes/config/config.php
@@ -135,16 +135,16 @@ class phpbb_config implements ArrayAccess, IteratorAggregate, Countable
*
* @param string $key The configuration option's name
* @param string $old_value Current configuration value
* @param string $value New configuration value
* @param bool $use_cache Whether this variable should be cached or if it
* changes too frequently to be efficiently cached.
* @return bool True if the value was changed, false otherwise.
*/
- public function set_atomic($key, $old_value, $value, $use_cache = true)
+ public function set_atomic($key, $old_value, $new_value, $use_cache = true)
{
if (!isset($this->config[$key]) || $this->config[$key] == $old_value)
{
- $this->config[$key] = $value;
+ $this->config[$key] = $new_value;
return true;
}
return false;
@@ -135,16 +135,16 @@ class phpbb_config implements ArrayAccess, IteratorAggregate, Countable
* @param string $key The configuration option's name
* @param string $old_value Current configuration value
- * @param string $value New configuration value
+ * @param string $new_value New configuration value
* @param bool $use_cache Whether this variable should be cached or if it
* changes too frequently to be efficiently cached.